import * as vue from 'vue';
import { Plugin, Ref, DefineComponent, CSSProperties, HtmlHTMLAttributes, ComputedRef, InjectionKey, VNode, UnwrapRef, UnwrapNestedRefs } from 'vue';
import { SandpackMessage, ListenerFunction, UnsubscribeFunction, BundlerState, SandpackError, SandpackBundlerFiles, SandpackClient, ReactDevToolsMode, SandpackLogLevel } from '@codesandbox/sandpack-client';
import { Extension } from '@codemirror/state';
import { EditorView, KeyBinding } from '@codemirror/view';
import * as _vue_shared from '@vue/shared';

declare function SanpackPlugin(): Plugin;

declare type SandpackClientDispatch = (msg: SandpackMessage, clientId?: string) => void;
declare type SandpackClientListen = (listener: ListenerFunction, clientId?: string) => UnsubscribeFunction;
declare type SandpackContext = SandpackState & {
    dispatch: SandpackClientDispatch;
    listen: SandpackClientListen;
};
interface SandpackState {
    bundlerState: BundlerState | undefined;
    openPaths: string[];
    activePath: string;
    startRoute?: string;
    autorun?: boolean;
    /**
     * Returns the current state of the editor, meaning that any
     * changes from the original `files` must return a `dirty` value;
     * otherwise, it'll return `pristine`
     */
    editorState: EditorState;
    error: SandpackError | null;
    files: SandpackBundlerFiles;
    environment?: SandboxEnvironment;
    status: SandpackStatus;
    initMode: SandpackInitMode;
    clients: Record<string, SandpackClient>;
    runSandpack: () => void;
    registerBundler: (iframe: HTMLIFrameElement, clientId: string) => void;
    unregisterBundler: (clientId: string) => void;
    updateFile: (pathOrFiles: string | SandpackFiles, code?: string) => void;
    updateCurrentFile: (newCode: string) => void;
    openFile: (path: string) => void;
    closeFile: (path: string) => void;
    deleteFile: (path: string) => void;
    setActiveFile: (path: string) => void;
    resetFile: (path: string) => void;
    resetAllFiles: () => void;
    registerReactDevTools: (value: ReactDevToolsMode) => void;
    /**
     * Element refs
     * Different components inside the SandpackProvider might register certain elements of interest for sandpack
     * eg: lazy anchor - if no component registers this, then the sandpack runs on mount, without lazy mode
     */
    lazyAnchorRef: Ref<HTMLDivElement>;
    /**
     * eg: error screen - if no component registers this, the bundler needs to show the custom error screen
     * When the value is boolean, we only care if the components have the responsibility to render the elements,
     * we don't need the actual element reference
     */
    errorScreenRegisteredRef: boolean;
    openInCSBRegisteredRef: boolean;
    loadingScreenRegisteredRef: boolean;
}
declare type SandpackStatus = 'initial' | 'idle' | 'running' | 'timeout' | 'done';
declare type EditorState = 'pristine' | 'dirty';
interface SandboxTemplate {
    files: Record<string, SandpackFile>;
    dependencies: Record<string, string>;
    devDependencies?: Record<string, string>;
    entry: string;
    main: string;
    environment: SandboxEnvironment;
}
interface SandpackFile {
    code: string;
    hidden?: boolean;
    active?: boolean;
    readOnly?: boolean;
}
declare type SandpackFiles = Record<string, string | SandpackFile>;
interface SandpackSetup {
    /**
     * Examples:
     * ```js
     * {
     *  "react": "latest",
     *  "@material-ui/core": "4.12.3",
     * }
     * ```
     */
    dependencies?: Record<string, string>;
    /**
     * Examples:
     * ```js
     * {
     *  "@types/react": "latest",
     * }
     * ```
     */
    devDependencies?: Record<string, string>;
    /**
     * The entry file is the starting point of the bundle process.
     *
     * If you change the path of the entry file, make sure you control all the files that go into the bundle process,
     * as prexisting settings in the template might not work anymore.
     */
    entry?: string;
    main?: string;
    files?: SandpackFiles;
    environment?: SandboxEnvironment;
}
/**
 * `immediate`: It immediately mounts all components, such as the code-editor
 * and the preview - this option might overload the memory usage
 * and resource from the browser on a page with multiple instances;
 *
 * `lazy`: Only initialize the components when the user is about to scroll
 * them to the viewport and keep these components mounted until the user
 * leaves the page - this is the default value;
 *
 * `user-visible`: Only initialize the components when the user is about
 * to scroll them to the viewport, but differently from lazy, this option
 * unmounts those components once it's no longer in the viewport.
 */
declare type SandpackInitMode = 'immediate' | 'lazy' | 'user-visible';
declare type SandboxEnvironment = 'angular-cli' | 'create-react-app' | 'create-react-app-typescript' | 'svelte' | 'parcel' | 'vue-cli' | 'static' | 'solid';
declare type SandpackPredefinedTemplate = 'angular' | 'react' | 'react-ts' | 'vanilla' | 'vanilla-ts' | 'vue' | 'vue3' | 'svelte' | 'solid';
declare type SandpackPredefinedTheme = 'light' | 'dark' | 'sandpack-dark' | 'night-owl' | 'aqua-blue' | 'github-light' | 'monokai-pro';
interface SandpackSyntaxStyle {
    color?: string;
    fontStyle?: 'normal' | 'italic';
    fontWeight?: 'normal' | 'bold' | '100' | '200' | '300' | '400' | '500' | '600' | '700' | '800' | '900';
    textDecoration?: 'none' | 'underline' | 'line-through' | 'underline line-through';
}
interface SandpackTheme {
    palette: {
        activeText: string;
        defaultText: string;
        inactiveText: string;
        activeBackground: string;
        defaultBackground: string;
        inputBackground: string;
        accent: string;
        errorBackground: string;
        errorForeground: string;
    };
    syntax: {
        plain: string | SandpackSyntaxStyle;
        comment: string | SandpackSyntaxStyle;
        keyword: string | SandpackSyntaxStyle;
        definition: string | SandpackSyntaxStyle;
        punctuation: string | SandpackSyntaxStyle;
        property: string | SandpackSyntaxStyle;
        tag: string | SandpackSyntaxStyle;
        static: string | SandpackSyntaxStyle;
        string?: string | SandpackSyntaxStyle;
    };
    typography: {
        bodyFont: string;
        monoFont: string;
        fontSize: string;
        lineHeight: string;
    };
}
declare type SandpackPartialTheme = DeepPartial<SandpackTheme>;
declare type SandpackThemeProp = SandpackPredefinedTheme | SandpackPartialTheme | 'auto';
/**
 * Custom properties to be used in the SandpackCodeEditor component,
 * some of which are exclusive to customize the CodeMirror instance.
 */
interface SandpackCodeOptions {
    /**
     * CodeMirror extensions for the editor state, which can
     * provide extra features and functionalities to the editor component.
     */
    extensions?: CodeEditorProps['extensions'];
    /**
     * Property to register CodeMirror extension keymap.
     */
    extensionsKeymap?: CodeEditorProps['extensionsKeymap'];
}
/**
 * @hidden
 */
declare type DeepPartial<Type> = {
    [Property in keyof Type]?: DeepPartial<Type[Property]>;
};
interface FileResolver {
    isFile: (path: string) => Promise<boolean>;
    readFile: (path: string) => Promise<string>;
}

interface SandpackOption {
    openPaths?: string[];
    activePath?: string;
    editorWidthPercentage?: number;
    editorHeight?: CSSProperties['height'];
    classes?: Record<string, string>;
    showNavigator?: boolean;
    showLineNumbers?: boolean;
    showInlineErrors?: boolean;
    showOpenInCodeSandbox?: boolean;
    showTabs?: boolean;
    closableTabs?: boolean;
    wrapContent?: boolean;
    /**
     * This provides a way to control how some components are going to
     * be initialized on the page. The CodeEditor and the Preview components
     * are quite expensive and might overload the memory usage, so this gives
     * a certain control of when to initialize them.
     */
    initMode?: SandpackInitMode;
    initModeObserverOptions?: IntersectionObserverInit;
    bundlerURL?: string;
    startRoute?: string;
    skipEval?: boolean;
    fileResolver?: FileResolver;
    externalResources?: string[];
    autorun?: boolean;
    recompileMode?: 'immediate' | 'delayed';
    recompileDelay?: number;
    codeEditor?: SandpackCodeOptions;
    /**
     * This disables editing of content by the user in all files.
     */
    readOnly?: boolean;
    /**
     * Controls the visibility of Read-only label, which will only
     * appears when `readOnly` is `true`
     */
    showReadOnly?: boolean;
    logLevel?: SandpackLogLevel;
}
interface SandpackProps {
    files?: SandpackFiles;
    template?: SandpackPredefinedTemplate;
    customSetup?: SandpackSetup;
    theme?: SandpackThemeProp;
    options?: SandpackOption;
}
/**
 * Sandpack component
 */
declare const Sandpack: DefineComponent<SandpackProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<SandpackProps>, {}>;

interface SandpackRunnerOption {
    showNavigator?: boolean;
    bundlerUrl?: string;
    startRoute?: string;
    classes?: Record<string, string>;
}
interface SandpackRunnerProps {
    code?: string;
    template?: SandpackPredefinedTemplate;
    customSetup?: SandpackSetup;
    theme?: SandpackThemeProp;
    options?: SandpackRunnerOption;
}
/**
 * SandpackRunner component
 */
declare const SandpackRunner: DefineComponent<SandpackRunnerProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<SandpackRunnerProps>, {}>;

/**
 * code area
 */
declare const CodeMirror: DefineComponent<CodeMirrorProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<CodeMirrorProps>, {}>;

declare type Decorators = Array<{
    className?: string;
    line: number;
    startColumn?: number;
    endColumn?: number;
    elementAttributes?: Record<string, string>;
}>;
declare type FileType = 'js' | 'jsx' | 'ts' | 'tsx' | 'css' | 'scss' | 'less' | 'html' | 'vue';
interface CodeMirrorRef {
    getCodemirror: () => EditorView | undefined;
}
interface CodeMirrorProps {
    onCodeUpdate?: (newCode: string) => void;
    id?: string;
    code: string;
    filePath?: string;
    fileType?: FileType;
    /**
     * @default false
     */
    showLineNumbers?: boolean;
    /**
     * @default false
     */
    showInlineErrors?: boolean;
    /**
     * @default false
     */
    wrapContent?: boolean;
    /**
     * @default 'pristine'
     */
    editorState?: EditorState;
    /**
     * This disables editing of content by the user in all files.
     * @default false
     */
    readOnly?: boolean;
    /**
     * Controls the visibility of Read-only label, which will only
     * appears when `readOnly` is `true`
     * @default true
     */
    showReadOnly?: boolean;
    /**
     * Provides a way to draw or style a piece of the content.
     */
    decorators?: Decorators;
    /**
     * @default 'lazy'
     */
    initMode: SandpackInitMode;
    /**
     * @default []
     */
    extensions?: Extension[];
    /**
     * @default []
     */
    extensionsKeymap?: Array<readonly KeyBinding[]>;
}
interface CodeEditorProps {
    customStyle?: CSSProperties;
    showTabs?: boolean;
    showLineNumbers?: boolean;
    showInlineErrors?: boolean;
    wrapContent?: boolean;
    closableTabs?: boolean;
    /**
     * This provides a way to control how some components are going to
     * be initialized on the page. The CodeEditor and the Preview components
     * are quite expensive and might overload the memory usage, so this gives
     * a certain control of when to initialize them.
     */
    initMode?: SandpackInitMode;
    /**
     * CodeMirror extensions for the editor state, which can
     * provide extra features and functionalities to the editor component.
     */
    extensions?: Extension[];
    /**
     * Property to register CodeMirror extension keymap.
     */
    extensionsKeymap?: Array<readonly KeyBinding[]>;
    id?: string;
    /**
     * This disables editing of the editor content by the user.
     */
    readOnly?: boolean;
    /**
     * Controls the visibility of Read-only label, which will only
     * appears when `readOnly` is `true`
     */
    showReadOnly?: boolean;
}
declare const SandpackCodeEditor: DefineComponent<CodeEditorProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<CodeEditorProps>, {}>;

interface FileTabsProps {
    /**
     * This adds a close button next to each file with a unique trigger to close it.
     */
    closableTabs?: boolean;
}
/**
 * FileTabs is a list of all open files, the active file, and its state.
 */
declare const FileTabs: DefineComponent<FileTabsProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<FileTabsProps>, {}>;

interface Props$2 {
    prefixedPath: string;
    files: SandpackBundlerFiles;
    selectFile: (path: string) => void;
    activePath: string;
    depth: number;
}
/**
 * Directory
 */
declare const Directory: DefineComponent<Props$2, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<Props$2>, {}>;

interface Props$1 {
    path: string;
    selectFile?: (path: string) => void;
    active?: boolean;
    onClick?: (e: MouseEvent) => void;
    depth: number;
    isDirOpen?: boolean;
}
/**
 * File
 */
declare const File: DefineComponent<Props$1, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<Props$1>, {}>;

interface Props {
    prefixedPath: string;
    files: SandpackBundlerFiles;
    selectFile: (path: string) => void;
    activePath: string;
    depth?: number;
}
/**
 * ModuleList
 */
declare const ModuleList: DefineComponent<Props, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<Props>, {}>;

/**
 * FileExplorer
 */
declare const FileExplorer: vue.DefineComponent<{}, () => JSX.Element, {}, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, vue.EmitsOptions, string, vue.ComponentProvideOptions, {
    name: string;
    inheritAttrs: true;
    setup(this: void): () => JSX.Element;
}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

interface CodeViewerProps {
    showTabs?: boolean;
    showLineNumbers?: boolean;
    /**
     * Provides a way to draw or style a piece of the content.
     */
    decorators?: Decorators;
    code?: string;
    wrapContent?: boolean;
    /**
     * This provides a way to control how some components are going to
     * be initialized on the page. The CodeEditor and the Preview components
     * are quite expensive and might overload the memory usage, so this gives
     * a certain control of when to initialize them.
     */
    initMode?: SandpackInitMode;
}
declare const SandpackCodeViewer: DefineComponent<CodeViewerProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<CodeViewerProps>, {}>;

interface NavigatorProps {
    clientId?: string;
    onURLChange?: (newURL: string) => void;
}
declare const Navigator: DefineComponent<NavigatorProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<NavigatorProps>, {}>;

interface RefreshButtonProps {
    clientId?: string;
}
declare const RefreshButton: DefineComponent<RefreshButtonProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<RefreshButtonProps>, {}>;

declare type ViewportSizePreset = 'iPhone X' | 'Pixel 2' | 'iPad' | 'Moto G4' | 'Surface Duo';
declare type ViewportSize = ViewportSizePreset | 'auto' | {
    width: string;
    height: string;
};
declare type ViewportOrientation = 'portrait' | 'landscape';
interface PreviewProps {
    customStyle?: CSSProperties;
    viewportSize?: ViewportSize;
    viewportOrientation?: ViewportOrientation;
    showNavigator?: boolean;
    showOpenInCodeSandbox?: boolean;
    showRefreshButton?: boolean;
    showSandpackErrorOverlay?: boolean;
    actionsChildren?: JSX.Element;
    children?: JSX.Element;
}

interface SandpackPreviewRef {
    /**
     * Retrieve the current Sandpack client instance from preview
     */
    getClient: () => SandpackClient | undefined;
    /**
     * Returns the client id, which will be used to
     * initialize a client in the main Sandpack context
     */
    clientId: string;
}
declare const SandpackPreview: DefineComponent<PreviewProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<PreviewProps>, {}>;

declare const SandpackTranspiledCode: DefineComponent<CodeViewerProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<CodeViewerProps>, {}>;

interface SandpackLayoutProps extends HtmlHTMLAttributes {
    theme?: SandpackThemeProp;
}
declare const SandpackLayout: DefineComponent<SandpackLayoutProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<SandpackLayoutProps>, {
    class?: any;
    inlist?: any;
}>;

declare const SandpackStack: DefineComponent<{
    customStyle?: CSSProperties | undefined;
}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<{
    customStyle?: CSSProperties | undefined;
}>, {}>;

declare const ErrorOverlay: vue.DefineComponent<{}, () => JSX.Element, {}, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, vue.EmitsOptions, string, vue.ComponentProvideOptions, {
    name: string;
    inheritAttrs: true;
    setup(this: void, _: Readonly<_vue_shared.LooseRequired<{
        [x: string & `on${string}`]: ((...args: any[]) => any) | undefined;
    } | {
        [x: string & `on${string}`]: ((...args: never) => any) | undefined;
    }>>, { slots }: vue.SetupContext<vue.EmitsOptions>): () => JSX.Element;
}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

interface LoadingOverlayProps {
    clientId?: string;
    /**
     * It enforces keeping the loading state visible,
     * which is helpful for external loading states.
     */
    loading?: boolean;
}
declare const LoadingOverlay: DefineComponent<LoadingOverlayProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<LoadingOverlayProps>, {}>;

declare const OpenInCodeSandboxButton: vue.DefineComponent<{}, () => JSX.Element, {}, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, vue.EmitsOptions, string, vue.ComponentProvideOptions, {
    name: string;
    inheritAttrs: true;
    setup(this: void): () => JSX.Element;
}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const UnstyledOpenInCodeSandboxButton: vue.DefineComponent<{}, () => JSX.Element, {}, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, vue.EmitsOptions, string, vue.ComponentProvideOptions, {
    name: string;
    inheritAttrs: true;
    setup(this: void, _: Readonly<_vue_shared.LooseRequired<{
        [x: string & `on${string}`]: ((...args: any[]) => any) | undefined;
    } | {
        [x: string & `on${string}`]: ((...args: never) => any) | undefined;
    }>>, { slots }: vue.SetupContext<vue.EmitsOptions>): () => JSX.Element;
}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

declare const RunButton: vue.DefineComponent<{}, () => JSX.Element, {}, {}, {}, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, vue.EmitsOptions, string, vue.ComponentProvideOptions, {
    name: string;
    inheritAttrs: true;
    setup(this: void): () => JSX.Element;
}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<vue.ExtractPropTypes<{}>>, {}>;

/**
 * This returns the current state of the active file
 * and a method to update its content.
 *
 * @category Hooks
 */
declare const useActiveCode: () => {
    code: Ref<string>;
    readOnly: Ref<boolean>;
    updateCode: (newCode: string) => void;
};

/**
 * @category Hooks
 */
declare const useErrorMessage: () => ComputedRef<SandpackError>;

declare type LoadingOverlayState = 'LOADING' | 'PRE_FADING' | 'FADING' | 'HIDDEN' | 'TIMEOUT';
declare const FADE_ANIMATION_DURATION = 200;
interface LoadingOverlayStateProp {
    clientId?: string;
    /**
     * It enforces keeping the loading state visible,
     * which is helpful for external loading states.
     */
    loading?: boolean;
}
/**
 * @category Hooks
 */
declare const useLoadingOverlayState: (props: LoadingOverlayStateProp) => vue.Ref<LoadingOverlayState>;

/**
 * @category Hooks
 */
declare const useSandpackNavigation: (clientId?: string | undefined) => {
    refresh: () => void;
    back: () => void;
    forward: () => void;
};

interface SandpackThemeProviderContext {
    theme: SandpackTheme;
    id: string;
}
declare const SandpackThemeContext: InjectionKey<SandpackThemeProviderContext>;
declare const SandpackThemeProvider: DefineComponent<{
    theme?: SandpackThemeProp | undefined;
}, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<{
    theme?: SandpackThemeProp | undefined;
}>, {}>;

/**
 * useSandpackTheme
 */
declare const useSandpackTheme: () => SandpackThemeProviderContext;

declare type ContextType<T> = any;
interface CreateContext<T> {
    Provider: DefineComponent<{}, () => VNode | VNode[] | undefined, any>;
    state: UnwrapRef<T> | T;
}
declare const createContext: <T extends Record<string, any>>(context: any, contextInjectKey?: InjectionKey<any>) => CreateContext<T>;
declare const useContext: <T>(contextInjectKey?: InjectionKey<any>, defaultValue?: any) => T;

interface UseSandpackReturnType {
    sandpack: SandpackState;
    dispatch: SandpackClientDispatch;
    listen: SandpackClientListen;
}
interface SandpackProviderState {
    files: SandpackBundlerFiles;
    environment?: SandboxEnvironment;
    activePath: string;
    openPaths: string[];
    startRoute?: string;
    bundlerState?: BundlerState;
    error: SandpackError | null;
    editorState: EditorState;
    renderHiddenIframe: boolean;
    initMode: SandpackInitMode;
    reactDevTools?: ReactDevToolsMode;
}
interface SandpackProviderProps {
    template?: SandpackPredefinedTemplate;
    customSetup?: SandpackSetup;
    activePath?: string;
    openPaths?: string[];
    recompileMode?: 'immediate' | 'delayed';
    recompileDelay?: number;
    autorun?: boolean;
    /**
     * This provides a way to control how some components are going to
     * be initialized on the page. The CodeEditor and the Preview components
     * are quite expensive and might overload the memory usage, so this gives
     * a certain control of when to initialize them.
     */
    initMode?: SandpackInitMode;
    initModeObserverOptions?: IntersectionObserverInit;
    bundlerURL?: string;
    logLevel?: SandpackLogLevel;
    startRoute?: string;
    skipEval?: boolean;
    fileResolver?: FileResolver;
    externalResources?: string[];
}
declare const SandpackStateContext: InjectionKey<UnwrapNestedRefs<SandpackState>>;
/**
 * SandpackProvider
 * Main context provider that should wraps your entire component.
 * Use * [`useSandpack`](/api/react/#usesandpack) hook, which gives you the entire context object to play with.
 */
declare const SandpackProvider: DefineComponent<SandpackProviderProps, {}, {}, vue.ComputedOptions, vue.MethodOptions, vue.ComponentOptionsMixin, vue.ComponentOptionsMixin, {}, string, vue.ComponentProvideOptions, {}, vue.VNodeProps & vue.AllowedComponentProps & vue.ComponentCustomProps, Readonly<SandpackProviderProps>, {}>;
/**
 * useSandpack
 */
declare function useSandpack(): UseSandpackReturnType;

/**
 * @category Theme
 */
declare const defaultLight: SandpackTheme;
/**
 * @category Theme
 */
declare const defaultDark: SandpackTheme;
/**
 * @category Theme
 */
declare const sandpackDark: SandpackTheme;
/**
 * @category Theme
 */
declare const aquaBlueTheme: SandpackTheme;
/**
 * @category Theme
 */
declare const githubLightTheme: SandpackTheme;
/**
 * @category Theme
 */
declare const nightOwlTheme: SandpackTheme;
/**
 * @category Theme
 */
declare const monokaiProTheme: SandpackTheme;
/**
 * @category Theme
 */
declare const SANDPACK_THEMES: Record<SandpackPredefinedTheme, SandpackTheme>;
/**
 * @category Theme
 */
declare const createThemeObject: (inputTheme?: SandpackThemeProp | undefined) => {
    id: string;
    theme: SandpackTheme;
};
/**
 * @category Theme
 */
declare const getThemeStyleSheet: (theme: SandpackTheme, themeId: string) => string;
/**
 * @category Theme
 */
declare const getSyntaxStyle: (token: string | SandpackSyntaxStyle) => SandpackSyntaxStyle;

declare const RunIcon: () => JSX.Element;
declare const BackwardIcon: () => JSX.Element;
declare const ForwardIcon: () => JSX.Element;
declare const RefreshIcon: () => JSX.Element;
declare const ExportIcon: () => JSX.Element;
declare const DirectoryIcon: ({ isOpen, }: {
    isOpen?: boolean | undefined;
}) => JSX.Element;
declare const FileIcon: () => JSX.Element;
declare const CloseIcon: () => JSX.Element;

export { BackwardIcon, CloseIcon, CodeMirror as CodeEditor, CodeEditorProps, CodeMirrorProps, CodeMirrorRef, CodeViewerProps, ContextType, CreateContext, Decorators, DeepPartial, Directory, DirectoryIcon, EditorState, ErrorOverlay, ExportIcon, FADE_ANIMATION_DURATION, File, FileExplorer, FileIcon, FileResolver, FileTabs, FileTabsProps, FileType, ForwardIcon, LoadingOverlay, LoadingOverlayProps, LoadingOverlayState, ModuleList, Navigator, OpenInCodeSandboxButton, PreviewProps, RefreshButton, RefreshIcon, RunButton, RunIcon, SANDPACK_THEMES, SandboxEnvironment, SandboxTemplate, Sandpack, SandpackClientDispatch, SandpackClientListen, SandpackCodeEditor, SandpackCodeOptions, SandpackCodeViewer, SandpackContext, SandpackFile, SandpackFiles, SandpackInitMode, SandpackLayout, SandpackLayoutProps, SandpackPartialTheme, SandpackPredefinedTemplate, SandpackPredefinedTheme, SandpackPreview, SandpackPreviewRef, SandpackProps, SandpackProvider, SandpackProviderProps, SandpackProviderState, SandpackRunner, SandpackRunnerProps, SandpackSetup, SandpackStack, SandpackState, SandpackStateContext, SandpackStatus, SandpackSyntaxStyle, SandpackTheme, SandpackThemeContext, SandpackThemeProp, SandpackThemeProvider, SandpackThemeProviderContext, SandpackTranspiledCode, UnstyledOpenInCodeSandboxButton, UseSandpackReturnType, ViewportOrientation, ViewportSize, ViewportSizePreset, aquaBlueTheme, createContext, createThemeObject, SanpackPlugin as default, defaultDark, defaultLight, getSyntaxStyle, getThemeStyleSheet, githubLightTheme, monokaiProTheme, nightOwlTheme, sandpackDark, useActiveCode, useContext, useErrorMessage, useLoadingOverlayState, useSandpack, useSandpackNavigation, useSandpackTheme };
